@@ -21,7 +21,6 @@
 __docformat__ = "restructuredtext en"
 
 import os
-import sys
 from os.path import join
 
 distname = "logilab-common"
@@ -29,7 +28,7 @@ modname = "common"
 subpackage_of = "logilab"
 subpackage_master = True
 
-numversion = (1, 9, 7)
+numversion = (1, 9, 8)
 version = ".".join([str(num) for num in numversion])
 
 license = "LGPL"  # 2.1 or later
@@ -47,6 +46,7 @@ __depends__ = {
     "setuptools": None,
     "mypy-extensions": None,
     "typing_extensions": None,
+    "importlib_metadata": ">=6,<7",
 }
 tests_require = [
     "pytz",
@@ -56,9 +56,6 @@ tests_require = [
 if os.name == "nt":
     __depends__["colorama"] = None
 
-if sys.version_info < (3, 8):
-    __depends__["importlib_metadata"] = None
-
 classifiers = [
     "Topic :: Utilities",
     "Programming Language :: Python",
