@@ -2,7 +2,7 @@
 from logilab.common.registry import yes, RegistrableObject, RegistrableInstance
 
 
-class Proxy(object):
+class Proxy:
     """annoying object should that not be registered, nor cause error"""
 
     def __getattr__(self, attr):
