@@ -501,7 +501,7 @@ class TestLoaderTC(TestCase):
             ("FooTC.whatever", 0),
         ]
         for pattern, expected_count in data:
-            yield self.assertRunCount, pattern, self.module, expected_count
+            self.assertRunCount(pattern, self.module, expected_count)
 
     def test_collect_with_pattern(self):
         data = [
@@ -516,7 +516,7 @@ class TestLoaderTC(TestCase):
             ("ab", 0),
         ]
         for pattern, expected_count in data:
-            yield self.assertRunCount, pattern, self.module, expected_count
+            self.assertRunCount(pattern, self.module, expected_count)
 
     def test_testcase_with_custom_metaclass(self):
         class mymetaclass(type):
@@ -553,7 +553,7 @@ class TestLoaderTC(TestCase):
             ("MyTestCase.whatever", 0),
         ]
         for pattern, expected_count in data:
-            yield self.assertRunCount, pattern, MyMod, expected_count
+            self.assertRunCount(pattern, MyMod, expected_count)
 
     def test_collect_everything_and_skipped_patterns(self):
         testdata = [
@@ -562,7 +562,7 @@ class TestLoaderTC(TestCase):
             (["foo", "bar"], 0),
         ]
         for skipped, expected_count in testdata:
-            yield self.assertRunCount, None, self.module, expected_count, skipped
+            self.assertRunCount(None, self.module, expected_count, skipped)
 
     def test_collect_specific_pattern_and_skip_some(self):
         testdata = [
@@ -571,7 +571,7 @@ class TestLoaderTC(TestCase):
             ("bar", ["bar"], 0),
         ]
         for runpattern, skipped, expected_count in testdata:
-            yield self.assertRunCount, runpattern, self.module, expected_count, skipped
+            self.assertRunCount(runpattern, self.module, expected_count, skipped)
 
     def test_skip_classname(self):
         testdata = [
@@ -579,7 +579,7 @@ class TestLoaderTC(TestCase):
             (["FooTC"], 1),
         ]
         for skipped, expected_count in testdata:
-            yield self.assertRunCount, None, self.module, expected_count, skipped
+            self.assertRunCount(None, self.module, expected_count, skipped)
 
     def test_skip_classname_and_specific_collect(self):
         testdata = [
@@ -587,7 +587,7 @@ class TestLoaderTC(TestCase):
             ("foo", ["FooTC"], 0),
         ]
         for runpattern, skipped, expected_count in testdata:
-            yield self.assertRunCount, runpattern, self.module, expected_count, skipped
+            self.assertRunCount(runpattern, self.module, expected_count, skipped)
 
     def test_nonregr_dotted_path(self):
         self.assertRunCount("FooTC.test_foo", self.module, 2)
@@ -615,7 +615,7 @@ class TestLoaderTC(TestCase):
             ("odd", 0),
         ]
         for pattern, expected_count in data:
-            yield self.assertRunCount, pattern, MyMod, expected_count
+            self.assertRunCount(pattern, MyMod, expected_count)
 
     def test_nonregr_class_skipped_option(self):
         class MyMod:
